"""Enums for opendrift"""

from enum import Enum

from pydantic.json_schema import GenerateJsonSchema


# Enum for drift_model
class DriftModelEnum(str, Enum):
    """Enum for drift models used in OpenDrift."""

    OceanDrift = "OceanDrift"
    LarvalFish = "LarvalFish"
    OpenOil = "OpenOil"
    Leeway = "Leeway"


# Enum for radius_type
class RadiusTypeEnum(str, Enum):
    """Enum for radius types used in OpenDrift."""

    gaussian = "gaussian"
    uniform = "uniform"


# Define Pydantic Enum classes
class DiffusivityModelEnum(str, Enum):
    """Enum for diffusivity models used in OpenDrift."""

    environment = "environment"
    stepfunction = "stepfunction"
    windspeed_Sundby1983 = "windspeed_Sundby1983"
    windspeed_Large1994 = "windspeed_Large1994"
    gls_tke = "gls_tke"
    constant = "constant"


class CoastlineActionEnum(str, Enum):
    """Enum for coastline actions used in OpenDrift."""

    none = "none"
    stranding = "stranding"
    previous = "previous"


class SeafloorActionEnum(str, Enum):
    """Enum for seafloor actions used in OpenDrift."""

    none = "none"
    lift_to_seafloor = "lift_to_seafloor"
    deactivate = "deactivate"
    previous = "previous"


class PlotTypeEnum(str, Enum):
    """Enum for plot types used in OpenDrift."""

    spaghetti = "spaghetti"
    animation = "animation"
    animation_profile = "animation_profile"
    oil = "oil"
    property = "property"
    all = "all"


class ObjectTypeEnum(str, Enum):
    """Enum for object types used in OpenDrift."""

    PERSON_IN_WATER_UNKNOWN = "Person-in-water (PIW), unknown state (mean values)"
    PIW_VERTICAL_PFD_TYPE_III_CONSCIOUS = ">PIW, vertical PFD type III conscious"
    PIW_SITTING_PFD_TYPE_I_OR_II = ">PIW, sitting, PFD type I or II"
    PIW_SURVIVAL_SUIT_FACE_UP = ">PIW, survival suit (face up)"
    PIW_SCUBA_SUIT_FACE_UP = ">PIW, scuba suit (face up)"
    PIW_DECEASED_FACE_DOWN = ">PIW, deceased (face down)"
    LIFE_RAFT_DEEP_BALLAST_GENERAL = "Life raft, deep ballast (DB) system, general, unknown capacity and loading (mean values)"
    LIFE_RAFT_4_14_PERSON_CANOPY_AVERAGE = (
        ">4-14 person capacity, deep ballast system, canopy (average)"
    )
    LIFE_RAFT_4_14_PERSON_NO_DROGUE = (
        ">>4-14 person capacity, deep ballast system, no drogue"
    )
    LIFE_RAFT_4_14_PERSON_CANOPY_NO_DROGUE_LIGHT = (
        ">>>4-14 person capacity, deep ballast system, canopy, no drogue, light loading"
    )
    LIFE_RAFT_4_14_PERSON_NO_DROGUE_HEAVY = (
        ">>>4-14 person capacity, deep ballast system, no drogue, heavy loading"
    )
    LIFE_RAFT_4_14_PERSON_CANOPY_WITH_DROGUE_AVERAGE = (
        ">>4-14 person capacity, deep ballast system, canopy, with drogue (average)"
    )
    LIFE_RAFT_4_14_PERSON_CANOPY_WITH_DROGUE_LIGHT = ">>>4-14 person capacity, deep ballast system, canopy, with drogue, light loading"
    LIFE_RAFT_4_14_PERSON_CANOPY_WITH_DROGUE_HEAVY = ">>>4-14 person capacity, deep ballast system, canopy, with drogue, heavy loading"
    LIFE_RAFT_15_50_PERSON_CANOPY_GENERAL = (
        ">15-50 person capacity, deep ballast system, canopy, general (mean values)"
    )
    LIFE_RAFT_15_50_PERSON_CANOPY_NO_DROGUE_LIGHT = (
        ">>15-50 person capacity, deep ballast system, canopy, no drogue, light loading"
    )
    LIFE_RAFT_15_50_PERSON_CANOPY_WITH_DROGUE_HEAVY = ">>15-50 person capacity, deep ballast system, canopy, with drogue, heavy loading"
    DEEP_BALLAST_CAPSIZED = "Deep ballast system, general (mean values), capsized"
    DEEP_BALLAST_SWAMPED = "Deep ballast system, general (mean values), swamped"
    LIFE_RAFT_SHALLOW_BALLAST_CANOPY_GENERAL = (
        "Life-raft, shallow ballast (SB) system AND canopy, general (mean values)"
    )
    LIFE_RAFT_SHALLOW_BALLAST_CANOPY_NO_DROGUE = (
        ">Life-raft, shallow ballast system, canopy, no drogue"
    )
    LIFE_RAFT_SHALLOW_BALLAST_CANOPY_WITH_DROGUE = (
        ">Life-raft, shallow ballast system AND canopy, with drogue"
    )
    LIFE_RAFT_SHALLOW_BALLAST_CANOPY_CAPSIZED = (
        "Life-raft, shallow ballast system AND canopy, capsized"
    )
    LIFE_RAFT_SHALLOW_BALLAST_NAVY_SEIE_NO_DROGUE = "Life Raft - Shallow ballast, canopy, Navy Sub Escape (SEIE) 1-man raft, NO drogue"
    LIFE_RAFT_SHALLOW_BALLAST_NAVY_SEIE_WITH_DROGUE = "Life Raft - Shallow ballast, canopy, Navy Sub Escape (SEIE) 1-man raft, with drogue"
    LIFE_RAFT_NO_BALLAST_GENERAL = (
        "Life-raft, no ballast (NB) system, general (mean values)"
    )
    LIFE_RAFT_NO_BALLAST_NO_CANOPY_NO_DROGUE = (
        ">Life-raft, no ballast system, no canopy, no drogue"
    )
    LIFE_RAFT_NO_BALLAST_NO_CANOPY_WITH_DROGUE = (
        ">Life-raft, no ballast system, no canopy, with drogue"
    )
    LIFE_RAFT_NO_BALLAST_WITH_CANOPY_NO_DROGUE = (
        ">Life-raft, no ballast system, with canopy, no drogue"
    )
    LIFE_RAFT_NO_BALLAST_WITH_CANOPY_WITH_DROGUE = (
        ">Life-raft, no ballast system, with canopy, with drogue"
    )
    SURVIVAL_CRAFT_USCG_SEA_RESCUE_KIT = "Survival Craft - USCG Sea Rescue Kit - 3 ballasted life rafts and 300 meter of line"
    LIFE_RAFT_4_6_PERSON_NO_BALLAST_WITH_CANOPY_NO_DROGUE = (
        "Life-raft, 4-6 person capacity, no ballast, with canopy, no drogue"
    )
    EVACUATION_SLIDE_WITH_LIFE_RAFT = (
        "Evacuation slide with life-raft, 46 person capacity"
    )
    SURVIVAL_CRAFT_SOLAS_HARD_SHELL = (
        "Survival Craft - SOLAS Hard Shell Life Capsule, 22 man"
    )
    # SURVIVAL_CRAFT_OVATEK_HARD_SHELL_LIGHT_NO_DROGUE = "Survival Craft - Ovatek Hard Shell Life Raft, 4 and 7-man, lightly loaded, no drogue (average)"
    SURVIVAL_CRAFT_OVATEK_HARD_SHELL_FULLY_DROGUED = "Survival Craft - Ovatek Hard Shell Life Raft, 4 and 7-man, fully loaded, drogued (average)"
    SURVIVAL_CRAFT_OVATEK_HARD_SHELL_4_MAN_LIGHT_NO_DROGUE = ">Survival Craft - Ovatek Hard Shell Life Raft, 4 man, lightly loaded, no drogue"
    SURVIVAL_CRAFT_OVATEK_HARD_SHELL_7_MAN_LIGHT_NO_DROGUE = ">Survival Craft - Ovatek Hard Shell Life Raft, 7 man, lightly loaded, no drogue"
    SURVIVAL_CRAFT_OVATEK_HARD_SHELL_4_MAN_FULLY_NO_DROGUE = (
        ">Survival Craft - Ovatek Hard Shell Life Raft, 4 man, fully loaded, drogued"
    )
    SURVIVAL_CRAFT_OVATEK_HARD_SHELL_7_MAN_FULLY_NO_DROGUE = (
        ">Survival Craft - Ovatek Hard Shell Life Raft, 7 man, fully loaded, drogued"
    )
    SEA_KAYAK_PERSON_ON_AFT_DECK = "Sea Kayak with person on aft deck"
    SURF_BOARD_PERSON = "Surf board with person"
    WINDSURFER_MAST_AND_SAIL_IN_WATER = "Windsurfer with mast and sail in water"
    SKIFF_MODIFIED_V = "Skiff - modified-v, cathedral-hull, runabout outboard powerboat"
    SKIFF_V_HULL = "Skiff, V-hull"
    SKIFFS_SWAMPED_AND_CAPSIZED = "Skiffs, swamped and capsized"
    SPORT_BOAT_MODIFIED_V_HULL = "Sport boat, no canvas (*1), modified V-hull"
    SPORT_FISHER_CENTER_CONSOLE = "Sport fisher, center console (*2), open cockpit"
    FISHING_VESSEL_GENERAL = "Fishing vessel, general (mean values)"
    FISHING_VESSEL_HAWAIIAN_SAMPAN = "Fishing vessel, Hawaiian Sampan (*3)"
    FISHING_VESSEL_JAPANESE_SIDE_STERN_TRAWLER = (
        ">Fishing vessel, Japanese side-stern trawler"
    )
    FISHING_VESSEL_JAPANESE_LONGLINER = ">Fishing vessel, Japanese Longliner (*3)"
    FISHING_VESSEL_KOREAN = ">Fishing vessel, Korean fishing vessel (*4)"
    FISHING_VESSEL_GILL_NETTER = ">Fishing vessel, Gill-netter with rear reel (*3)"
    COASTAL_FREIGHTER = "Coastal freighter. (*5)"
    SAILBOAT_MONO_HULL = "Sailboat Mono-hull (Average)"
    SAILBOAT_MONO_HULL_DISMASTED = ">Sailboat Mono-hull (Dismasted, Average)"
    SAILBOAT_MONO_HULL_DISMASTED_RUDDER = (
        ">>Sailboat Mono-hull (Dismasted - rudder amidships)"
    )
    SAILBOAT_MONO_HULL_DISMASTED_RUDDER_MISSING = (
        ">>Sailboat Mono-hull (Dismasted - rudder missing)"
    )
    SAILBOAT_MONO_HULL_BARE_MASTED = ">Sailboat Mono-hull (Bare-masted,  Average)"
    SAILBOAT_MONO_HULL_BARE_MASTED_RUDDER = (
        ">>Sailboat Mono-hull (Bare-masted, rudder amidships)"
    )
    SAILBOAT_MONO_HULL_BARE_MASTED_RUDDER_HOVE_TO = (
        ">>Sailboat Mono-hull (Bare-masted, rudder hove-to)"
    )
    SAILBOAT_MONO_HULL_FIN_KEEL = (
        "Sailboat Mono-hull, fin keel, shallow draft (was SAILBOAT-2)"
    )
    SUNFISH_SAILING_DINGY = "Sunfish sailing dingy  -  Bare-masted, rudder missing"
    FISHING_VESSEL_DEBRIS = "Fishing vessel debris"
    SELF_LOCATING_DATUM_MARKER_BUOY = "Self-locating datum marker buoy - no windage"
    NAVY_SUBMARINE_EPIRB = "Navy Submarine EPIRB (SEPIRB)"
    BAIT_WHARF_BOX = "Bait/wharf box, holds a cubic metre of ice, mean values (*6)"
    BAIT_WHARF_BOX_FULL_LOAD = (
        ">Bait/wharf box, holds a cubic metre of ice, full loaded"
    )
    OIL_DRUM = "55-gallon (220 l) Oil Drum"
    CONTAINER_40_FT = "Scaled down (1:3) 40-ft Container (70% submerged)"
    CONTAINER_20_FT = "20-ft Container (80% submerged)"
    WWII_L_MK2_MINE = "WWII L-MK2 mine"
    IMMIGRATION_VESSEL_NO_SAIL = "Immigration vessel, Cuban refugee-raft, no sail (*7)"
    IMMIGRATION_VESSEL_WITH_SAIL = (
        "Immigration vessel, Cuban refugee-raft, with sail (*7)"
    )
    SEWAGE_FLOATABLES = "Sewage floatables, tampon applicator"
    MEDICAL_WASTE = "Medical waste (mean values)"
    MEDICAL_WASTE_VIALS = ">Medical waste, vials"
    MEDICAL_WASTE_VIALS_LARGE = ">>Medical waste, vials, large"
    MEDICAL_WASTE_VIALS_SMALL = ">>Medical waste, vials, small"
    MEDICAL_WASTE_SYRINGES = ">Medical waste, syringes"
    MEDICAL_WASTE_SYRINGES_LARGE = ">>Medical waste, syringes, large"
    MEDICAL_WASTE_SYRINGES_SMALL = ">>Medical waste, syringes, small"


# # Make OilTypeEnum with:
# from enum import Enum
# import opendrift.models.openoil.adios.dirjs as dirjs
# oil = [(oil.id, oil.name) for oil in dirjs.oils(limit=1300)]
# with open("notebook_out.txt", "w") as file:
#     file.write(str(oil))


class OilTypeEnum(str, Enum):
    """Contains ADIOS database id as name and title as value.

    Either id or title can be input to OpenDriftModel (or the config classes)
    and work fine and be validated.
    """

    AD00010 = "ABU SAFAH, ARAMCO"
    AD00020 = "ALASKA NORTH SLOPE"
    AD00024 = "ALBERTA"
    AD00025 = "ALBERTA SWEET MIXED BLEND"
    AD00026 = "ALGERIAN BLEND"
    AD00028 = "ALGERIAN CONDENSATE, CITGO"
    AD00031 = "AMAULIGAK"
    AD00039 = "ARABIAN EXTRA LIGHT, PHILLIPS"
    AD00040 = "ARABIAN EXTRA LIGHT, STAR ENTERPRISE"
    AD00041 = "ARABIAN EXTRA LIGHT, ARAMCO"
    AD00042 = "ARABIAN HEAVY"
    AD00044 = "ARABIAN HEAVY, CITGO"
    AD00046 = "ARABIAN HEAVY, EXXON"
    AD00047 = "ARABIAN HEAVY, AMOCO"
    AD00049 = "ARABIAN HEAVY, STAR ENTERPRISE"
    AD00050 = "ARABIAN HEAVY, ARAMCO"
    AD00053 = "ARABIAN LIGHT, CITGO"
    AD00055 = "ARABIAN LIGHT, PHILLIPS"
    AD00057 = "ARABIAN LIGHT, STAR ENTERPRISE"
    AD00058 = "ARABIAN LIGHT, ARAMCO"
    AD00062 = "ARABIAN MEDIUM, EXXON"
    AD00063 = "ARABIAN MEDIUM, PHILLIPS"
    AD00064 = "ARABIAN MEDIUM, AMOCO"
    AD00065 = "ARABIAN MEDIUM, STAR ENTERPRISE"
    AD00066 = "ARABIAN MEDIUM, CHEVRON"
    AD00070 = "ARGYL"
    AD00080 = "ATKINSON"
    AD00084 = "AUTOMOTIVE GASOLINE, EXXON"
    AD00085 = "AVALON"
    AD00092 = "AVIATION GASOLINE 100LL, STAR ENTERPRISE"
    AD00094 = "AVIATION GASOLINE 80"
    AD00095 = "BACHAGUERO, CITGO"
    AD00099 = "BACHAQUERO 17, EXXON"
    AD00100 = "BACHEQUERO HEAVY"
    AD00101 = "BACHEQUERO MEDIUM"
    AD00102 = "BAHIA"
    AD00103 = "BAKR"
    AD00105 = "BANOCO ABU SAFAH, ARAMCO"
    AD00109 = "BASRAH"
    AD00110 = "BASRAH, EXXON"
    AD00115 = "BASS STRAIT"
    AD00121 = "BCF 13"
    AD00122 = "BCF 17"
    AD00124 = "BCF 22, CITGO"
    AD00127 = "BCF 17, AMOCO"
    AD00132 = "BELAYIM (MARINE)"
    AD00133 = "BELAYIM (LAND)"
    AD00138 = "BENT HORN A-02"
    AD00142 = "BERRI A-21, ARAMCO"
    AD00143 = "BERYL"
    AD00147 = "BFC 21.9, CITGO"
    AD00159 = "BONNY LIGHT, CITGO"
    AD00162 = "BONNY MEDIUM, CITGO"
    AD00163 = "BONNY MEDIUM, AMOCO"
    AD00165 = "BORHOLLA"
    AD00171 = "BOSCAN, AMOCO"
    AD00174 = "BOW RIVER BLENDED"
    AD00179 = "BRASS RIVER, CITGO"
    AD00181 = "BRASS RIVER, PHILLIPS"
    AD00185 = "BREGA, ARCO"
    AD00187 = "BRENT"
    AD00189 = "BRENT, CITGO"
    AD00190 = "BRENT, PHILLIPS"
    AD00196 = "BRENT MIX, EXXON"
    AD00197 = "BRENT SPAR"
    AD00204 = "BUCHAN"
    AD00208 = "BUNKER C FUEL OIL"
    AD00213 = "CABINDA, CITGO"
    AD00215 = "CABINDA, PHILLIPS"
    AD00224 = "CAMAR"
    AD00226 = "CANDON SEC, PHILLIPS"
    AD00227 = "CANO LIMON, CITGO"
    AD00228 = "CANO LIMON, PHILLIPS"
    AD00254 = "COBAN BLEND"
    AD00255 = "COBAN BLEND, PHILLIPS"
    AD00257 = "COHASSET"
    AD00259 = "COLD LAKE, EXXON"
    AD00262 = "COLD LAKE BLEND, ESSO"
    AD00263 = "COLD LAKE DILUENT, ESSO"
    AD00269 = "COOK INLET, DRIFT RIVER TERMINAL"
    AD00270 = "CORMORANT"
    AD00279 = "UNION, UNOCAL"
    AD00284 = "CYRUS, ITOPF"
    AD00289 = "DANMARK"
    AD00293 = "DF2 SUMMER (DIESEL), TESORO"
    AD00294 = "DF2 WINTER (DIESEL), TESORO"
    AD00297 = "DIESEL"
    AD00301 = "DJENO, PHILLIPS"
    AD00315 = "DUNLIN"
    AD00316 = "DURI, PHILLIPS"
    AD00319 = "EAST TEXAS"
    AD00322 = "EC 195-CONDENSATE, PHILLIPS"
    AD00328 = "EKOFISK"
    AD00329 = "EKOFISK, CITGO"
    AD00332 = "EKOFISK, EXXON"
    AD00333 = "EKOFISK, PHILLIPS"
    AD00346 = "ELECTRICAL INSULATING OIL (VIRGIN)"
    AD00354 = "EMPIRE ISLAND, AMOCO"
    AD00362 = "ESCALANTE, PHILLIPS"
    AD00365 = "ESCRAVOS, AMOCO"
    AD00366 = "ESCRAVOS, CHEVRON"
    AD00376 = "FAO, CITGO"
    AD00377 = "FCC HEAVY CYCLE OIL"
    AD00379 = "FEDERATED"
    AD00383 = "FLOTTA, CITGO"
    AD00384 = "FLOTTA"
    AD00385 = "FLOTTA, PHILLIPS"
    AD00386 = "FLOTTA MIX"
    AD00388 = "FORCADOS, CITGO"
    AD00389 = "FORCADOS, AMOCO"
    AD00391 = "FORKED ISLAND TERMINAL, AMOCO"
    AD00393 = "FORTIES"
    AD00397 = "FOSTERTON"
    AD00403 = "FUEL OIL NO.1 (AVJET A), STAR ENTERPRISE"
    AD00404 = "FUEL OIL NO.1 (DIESEL/HEATING FUEL), PETRO STAR"
    AD00412 = "FUEL OIL NO.1 (JET FUEL A)"
    AD00413 = "FUEL OIL NO.1 (JET FUEL A-1)"
    AD00414 = "FUEL OIL NO.1 (JET FUEL B)"
    AD00416 = "FUEL OIL NO.1 (KEROSENE) "
    AD00431 = "FUEL OIL NO.2 (DIESEL), STAR ENTERPRISE"
    AD00433 = "FUEL OIL NO.2 (HO/DIESEL), EXXON"
    AD00448 = "FURRIAL, CITGO"
    AD00449 = "FURRIAL/MESA 28, EXXON"
    AD00486 = "GIPPSLAND, EXXON"
    AD00487 = "GIPPSLAND MIX, ITOPF"
    AD00506 = "GUAFITA, CITGO"
    AD00513 = "GULF OF SUEZ, PHILLIPS"
    AD00516 = "GULLFAKS, EXXON"
    AD00530 = "HEAVY LAKE MIX"
    AD00531 = "HEAVY REFORMATE"
    AD00534 = "HI 317, PHILLIPS"
    AD00535 = "HI 330/349 CONDENSATE, PHILLIPS"
    AD00536 = "HI 561-GRAND CHENIER, PHILLIPS"
    AD00537 = "HI A-310-B/CONDENSATE, PHILLIPS"
    AD00540 = "HIGH ISLAND, AMOCO"
    AD00541 = "HIGH ISLAND BLOCK 154, PHILLIPS"
    AD00554 = "HUTTON"
    AD00563 = "INTERPROVINCIAL"
    AD00565 = "IPPL LIGHT SOUR BLEND"
    AD00573 = "ISSUNGNAK"
    AD00575 = "ISTHMUS, CITGO"
    AD00577 = "ISTHMUS, PHILLIPS"
    AD00579 = "ISTHMUS/MAYA BLEND"
    AD00580 = "ISTHMUS/REFORMA/CACTUS, API"
    AD00589 = "JOBO"
    AD00590 = "JOBO/MORICHAL, ITOPF"
    AD00602 = "KHAFJI"
    AD00610 = "KIRKUK"
    AD00611 = "KIRKUK, EXXON"
    AD00615 = "KOAKOAK 0-22"
    AD00619 = "KOLE MARINE, AMOCO"
    AD00622 = "KOPANOAR 2I-44"
    AD00623 = "KOPANOAR M-13"
    AD00624 = "KOPANOAR M-13A"
    AD00625 = "KUPARUK"
    AD00630 = "KUWAIT, ARCO"
    AD00631 = "KUWAIT CRUDE OIL (LITERATURE VALUES)"
    AD00633 = "KUWAIT LIGHT, PHILLIPS"
    AD00638 = "LA ROSA"
    AD00644 = "LAGO MEDIO"
    AD00647 = "LAGO TRECO, CITGO"
    AD00648 = "LAGOTRECO"
    AD00649 = "LAGUNA"
    AD00650 = "LAGUNA, CITGO"
    AD00651 = "LAGUNA 22, CITGO"
    AD00652 = "LAGUNA BLEND 24, CITGO"
    AD00665 = "LALANG"
    AD00667 = "LARG TRECO MEDIUM, CITGO"
    AD00672 = "LEDUC WOODBEND"
    AD00674 = "LEONA, CITGO"
    AD00680 = "LIGHT SOUR BLEND"
    AD00682 = "LIUHUA, AMOCO"
    AD00685 = "LOKELE, CITGO"
    AD00686 = "LOKELE, EXXON"
    AD00697 = "LUBRICATING OIL (AUTO ENGINE OIL, VIRGIN)"
    AD00716 = "MARALAGO 22, CITGO"
    AD00717 = "MARGHAM"
    AD00718 = "MARIB, PHILLIPS"
    AD00721 = "MARINE DIESEL FUEL OIL"
    AD00725 = "MARJAN/ZULUF, ARAMCO"
    AD00732 = "MAYA, CITGO"
    AD00734 = "MAYA, EXXON"
    AD00735 = "MAYA, PHILLIPS"
    AD00736 = "MAYA, AMOCO"
    AD00738 = "MAYOGIAK"
    AD00741 = "MCARTHUR RIVER"
    AD00748 = "MENEMOTA"
    AD00750 = "MENEMOTA, CITGO"
    AD00756 = "MESA 28, CITGO"
    AD00757 = "MESA 30, CITGO"
    AD00760 = "MIDDLE GROUND SHOAL"
    AD00778 = "MORICHAL"
    AD00809 = "NEKTORALIK K-59"
    AD00810 = "NEKTORALIK K-59A"
    AD00811 = "NERLERK"
    AD00812 = "NERLERK M-98B"
    AD00817 = "NIGERIAN EXP. B1"
    AD00818 = "NIGERIAN LGT G"
    AD00819 = "NIGERIAN LGT M"
    AD00820 = "NIGERIAN LIGHT"
    AD00823 = "NIGERIAN MEDIUM"
    AD00824 = "NIKISKI"
    AD00825 = "NINIAN"
    AD00827 = "NINIAN, CITGO"
    AD00834 = "NORTH EAST TEXAS"
    AD00836 = "NORTH SLOPE"
    AD00837 = "NORTH SLOPE, CITGO"
    AD00838 = "NORTH SLOPE, PHILLIPS"
    AD00839 = "NOWRUZ"
    AD00846 = "OGUENDJO, AMOCO"
    AD00849 = "OLMECA, CITGO"
    AD00852 = "OMAN"
    AD00853 = "OMAN, PHILLIPS"
    AD00855 = "OQUENDJO"
    AD00858 = "ORIENTE, CITGO"
    AD00859 = "OSEBERG"
    AD00860 = "OSEBERG, EXXON"
    AD00861 = "OSEBERG, PHILLIPS"
    AD00864 = "PALANCA"
    AD00868 = "PANUCO"
    AD00869 = "PANUKE"
    AD00875 = "PARENTIS"
    AD00880 = "PECAN ISLAND, AMOCO"
    AD00882 = "PEMBINA"
    AD00893 = "PILON"
    AD00894 = "PILON, CITGO"
    AD00896 = "PILON-ANACO WAX, CITGO"
    AD00897 = "PIPER"
    AD00898 = "PITAS POINT"
    AD00899 = "PL COMPOSITE, STAR ENTERPRISE"
    AD00900 = "PLATFORM B"
    AD00913 = "PREMIUM UNLEADED GASOLINE, STAR ENTERPRISE"
    AD00924 = "QUA IBOE, PHILLIPS"
    AD00932 = "RAGUSA"
    AD00935 = "RANGELAND-SOUTH LIGHT AND MEDIUM"
    AD00937 = "RAS LANUF"
    AD00938 = "RATNA"
    AD00940 = "REDWATER"
    AD00944 = "RESIDUAL FUEL 900, TESORO"
    AD00949 = "RIO ZULIA"
    AD00964 = "SAN JOACHIM"
    AD00971 = "SANTA CRUZ"
    AD00973 = "SANTA MARIA"
    AD00980 = "SARIR, ITOPF"
    AD00983 = "SCHOONEBEEK"
    AD00995 = "SHARJAH"
    AD00999 = "SHIP SHOAL 133, PHILLIPS"
    AD01006 = "SIRTICA"
    AD01008 = "SMI 147, PHILLIPS"
    AD01009 = "SMI 66, PHILLIPS"
    AD01022 = "SOUR BLEND"
    AD01025 = "SOUTH LOUISIANA"
    AD01030 = "SOUTH WEST TEXAS LIGHT"
    AD01031 = "SOYO"
    AD01046 = "SUEZ MIX"
    AD01050 = "SUNNILAND, EXXON"
    AD01054 = "SWEET BLEND"
    AD01058 = "TACHING"
    AD01059 = "TACHING"
    AD01062 = "TAKULA, API"
    AD01063 = "TAKULA, CITGO"
    AD01064 = "TAKULA, CHEVRON"
    AD01070 = "TARSIUT"
    AD01071 = "TARSIUT A-25"
    AD01076 = "TERRA NOVA"
    AD01077 = "TERRA NOVA K-08 DST #1"
    AD01078 = "TERRA NOVA K-08 DST #2"
    AD01079 = "TERRA NOVA K-08 DST #3"
    AD01080 = "TERRA NOVA K-08 DST #4"
    AD01081 = "TEXAS GULF COAST HEAVY"
    AD01082 = "TEXAS GULF COAST LIGHT"
    AD01083 = "TEXTRACT, STAR ENTERPRISE"
    AD01088 = "TIA JUANA"
    AD01094 = "TIA JUANA LIGHT, CITGO"
    AD01096 = "TIA JUANA MEDIUM"
    AD01097 = "TIA JUANA MEDIUM, CITGO"
    AD01098 = "TIA JUANA MEDIUM, ARCO"
    AD01100 = "TIA JUANA PESADO"
    AD01118 = "TRADING BAY (OFFSHORE COOK INLET)"
    AD01119 = "TRANSMOUNTAIN BLEND"
    AD01121 = "TRINIDAD"
    AD01133 = "ULA"
    AD01134 = "UMM SHAIF"
    AD01135 = "UMM SHARIF, PHILLIPS"
    AD01137 = "UNLEADED INTERM GASOLINE, STAR ENTERPRISE"
    AD01139 = "UPPER ZAKUM, PHILLIPS"
    AD01140 = "URAL"
    AD01141 = "UVILUK"
    AD01147 = "VENEZUELA MIX"
    AD01155 = "WAFRA EOCENE"
    AD01162 = "WC BLOCK 45 BEACH-CONDENSATE, PHILLIPS"
    AD01171 = "WEST GENERAL TEXAS"
    AD01172 = "WEST NEDERLAND"
    AD01175 = "WEST TEXAS ELLENBURGER"
    AD01177 = "WEST TEXAS LIGHT"
    AD01180 = "WEYBURN-MIDALE"
    AD01184 = "YANBU ARABIAN LIGHT, ARAMCO"
    AD01186 = "YOMBO, AMOCO"
    AD01189 = "ZAIRE, API"
    AD01191 = "ZAIRE, CHEVRON"
    AD01193 = "ZAKUA"
    AD01194 = "ZAKUM"
    AD01200 = "ZETA NORTH"
    AD01215 = "MARINE DIESEL F-76, MANCHESTER FUEL"
    AD01217 = "KERN COUNTY BLEND"
    AD01219 = "VENEZUELA RECON"
    AD01220 = "DAQIN"
    AD01221 = "SHIAN LI"
    AD01222 = "HUIZHOU"
    AD01223 = "WEST TEXAS INTERMEDIATE, OIL & GAS"
    AD01225 = "MAIN PASS 140, PENNZOIL"
    AD01232 = "JABIRU, BHP PETROLEUM"
    AD01233 = "JABIRU 1A, BHP PETROLEUM"
    AD01235 = "KUTUBU LIGHT, BHP PETROLEUM"
    AD01236 = "GIPPSLAND, BHP PETROLEUM"
    AD01258 = "UDANG, OIL & GAS"
    AD01262 = "DURI, OIL & GAS"
    AD01264 = "SOVIET EXPORT, OIL & GAS"
    AD01269 = "BARROW ISLAND, OIL & GAS"
    AD01301 = "BELAYIM, OIL & GAS"
    AD01326 = "SHARJAH, OIL & GAS"
    AD01345 = "LLOYDMINSTER, OIL & GAS"
    AD01346 = "ALASKA NORTH SLOPE, OIL & GAS"
    AD01357 = "STATJORD, OIL & GAS"
    AD01369 = "FLOTTA, OIL & GAS"
    AD01378 = "FORTIES, OIL & GAS"
    AD01392 = "ESCRAVOS, OIL & GAS"
    AD01401 = "BELIDA, OIL & GAS"
    AD01411 = "RABBI, COASTAL EAGLE POINT OIL"
    AD01412 = "SOLVENT NEUTRAL OIL 320, STAR ENTERPRISE"
    AD01413 = "ROSSIIELF, RUSSIAN JOINT STOCK CO"
    AD01419 = "KUTUBU, AMSA"
    AD01420 = "GRIFFIN, AMSA"
    AD01421 = "NSW CONDENSATE, AMSA"
    AD01424 = "KABINDA, GALLAGER MARINE"
    AD01425 = "NEMBA, GALLAGER MARINE"
    AD01427 = "FUEL OIL NO.2, AMOCO"
    AD01428 = "TEAK AND SAMAAN, AMOCO"
    AD01429 = "GALEOTA MIX, AMOCO"
    AD01430 = "POUI, AMOCO"
    AD01432 = "QATAR/DUKHAM, CHEVRON"
    AD01433 = "ALGERIAN CONDENSATE, SHELL OIL"
    AD01434 = "ARABIAN MEDIUM, SHELL OIL"
    AD01435 = "ARUN CONDENSATE, SHELL OIL"
    AD01436 = "BACHAQUERO, SHELL OIL"
    AD01437 = "BADAK, SHELL OIL"
    AD01438 = "BETA PRODUCTION, SHELL OIL"
    AD01439 = "BONITO P/L SOUR, SHELL OIL"
    AD01440 = "BONNY LIGHT, SHELL OIL"
    AD01441 = "BRASS RIVER, SHELL OIL"
    AD01442 = "CABINDA BLEND, SHELL OIL"
    AD01443 = "COGNAC-BLOCK 194, SHELL OIL"
    AD01444 = "DJENO, SHELL OIL"
    AD01445 = "ERAWAN CONDENSATE, SHELL OIL"
    AD01446 = "ESCRAVOS, SHELL OIL"
    AD01447 = "ETCHEGOIN, SHELL OIL"
    AD01448 = "FLOTTA, SHELL OIL"
    AD01449 = "FORCADOS, SHELL OIL"
    AD01450 = "FORTIES, SHELL OIL"
    AD01451 = "FURRIAL, SHELL OIL"
    AD01452 = "GIPPSLAND, SHELL OIL"
    AD01453 = "GREEN CANYON, SHELL OIL"
    AD01454 = "GULLFAKS, SHELL OIL"
    AD01455 = "HARDING, SHELL OIL"
    AD01456 = "HIGH ISLAND SWEET, SHELL OIL"
    AD01457 = "HUNTINGTON BEACH, SHELL OIL"
    AD01458 = "ISTHMUS, SHELL OIL"
    AD01460 = "JABIRU, SHELL OIL"
    AD01461 = "KERN RIVER-SWEPI, SHELL OIL"
    AD01462 = "KIRKUK, SHELL OIL"
    AD01463 = "KOLE, SHELL OIL"
    AD01464 = "KUTUBU, SHELL OIL"
    AD01465 = "LAGOCINCO, SHELL OIL"
    AD01466 = "LAGOMAR, SHELL OIL"
    AD01467 = "LAGOTRECO, SHELL OIL"
    AD01468 = "LOKELE, SHELL OIL"
    AD01469 = "LLOYDMINSTER, SHELL OIL"
    AD01470 = "ARABIAN LIGHT, SHELL OIL"
    AD01471 = "LORETO, SHELL OIL"
    AD01472 = "LUCINA, SHELL OIL"
    AD01473 = "MAIN PASS 49 CONDENSATE, SHELL OIL"
    AD01474 = "MAYA, SHELL OIL"
    AD01475 = "MANDJI, SHELL OIL"
    AD01476 = "MURBAN, SHELL OIL"
    AD01477 = "OLMECA, SHELL OIL"
    AD01478 = "OMAN, SHELL OIL"
    AD01479 = "ORIENTE, SHELL OIL"
    AD01480 = "OSEBERG, SHELL OIL"
    AD01481 = "PALANCA, SHELL OIL"
    AD01482 = "PECAN ISLAND, SHELL OIL"
    AD01483 = "QUA IBOE, SHELL OIL"
    AD01484 = "RABI BLEND, SHELL OIL"
    AD01485 = "RABI-KOUNGA, SHELL OIL"
    AD01486 = "SAHARAN BLEND BEJAIA, SHELL OIL"
    AD01487 = "SAHARAN BLEND ARZEW, SHELL OIL"
    AD01488 = "SKUA, SHELL OIL"
    AD01489 = "SOYO, SHELL OIL"
    AD01490 = "TIA JUANA LIGHT, SHELL OIL"
    AD01491 = "TIERRA DEL FUEGO, SHELL OIL"
    AD01492 = "VENTURA SHELL TAYLOR LEASE, SHELL OIL"
    AD01493 = "VIOSCA KNOLL 826, SHELL OIL"
    AD01494 = "WEST DELTA BLOCK 89, SHELL OIL"
    AD01495 = "WEST LAKE VERRET, SHELL OIL"
    AD01496 = "XIJIANG, SHELL OIL"
    AD01497 = "YORBA LINDA SHELL, SHELL OIL"
    AD01498 = "YOWLUMNE, SHELL OIL"
    AD01499 = "ZAIRE, SHELL OIL"
    AD01500 = "JET A-1,  MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01501 = "DUAL PURPOSE KEROSINE,  MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01507 = "MCKEE BLEND, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01508 = "MAUI F SAND, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01510 = "MCKEE BLEND 50%, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01511 = "MCKEE BLEND 25%, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01512 = "MCKEE BLEND 10% NGAT-1, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01513 = "MCKEE BLEND 10% NGAT-2, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01514 = "MCKEE BLEND 10% NGAT-3, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01515 = "HANDIL, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01517 = "BARROW ISLAND, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01519 = "BRASS RIVER, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01520 = "DUBAI, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01521 = "MURBAN, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01522 = "MAUI B, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01524 = "KUTUBU, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01525 = "GRIFFIN, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01528 = "MIRI LIGHT, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01529 = "SYNGAS, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01530 = "LABUAN, MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01533 = "OMAN,  MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01535 = "THEVENARD,  MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01536 = "WIDURI,  MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01537 = "KHAFJI,  MARITIME SAFETY AUTHORITY OF NEW ZEALAND"
    AD01552 = "FORCADOS, BP"
    AD01553 = "WEST TEXAS SOUR, BP"
    AD01554 = "LIGHT LOUISIANNA SWEET, BP"
    AD01556 = "RINCON DE LOS SAUCES, OIL & GAS"
    AD01557 = "MEDANITO, OIL & GAS"
    AD01561 = "ESCRAVOS SWAMP BLEND, CHEVRON"
    AD01562 = "BENIN RIVER, CHEVRON"
    AD01567 = "NORTHWEST CHARGE STOCK, CHEVRON"
    AD01577 = "ARABIAN EXTRA LIGHT, BOUCHARD"
    AD01579 = "BRENT, SUN"
    AD01581 = "MONTEREY, TORCH"
    AD01585 = "ODUDU, EXXON"
    AD01612 = "BELIDA"
    AD01614 = "BINTULU"
    AD01621 = "BUNKER C FUEL OIL (ALASKA)"
    AD01622 = "BUNKER C FUEL OIL (IRVING WHALE)"
    AD01627 = "CANO LIMON"
    AD01634 = "CUSIANA"
    AD01652 = "FCC FEED"
    AD01654 = "FCC MEDIUM CYCLE OIL"
    AD01676 = "IFO 180"
    AD01705 = "ORIENTE"
    AD01706 = "ORIMULSION"
    AD01707 = "PENNINGTON"
    AD01726 = "SARIR"
    AD01732 = "SIBERIAN BLEND"
    AD01739 = "SOUTH PASS BLOCK 67"
    AD01758 = "NEWFOUNDLAND OFFSHORE BURN EXPERIMENT"
    AD01765 = "FUEL OIL NO.1 (JET B, ALASKA)"
    AD01774 = "DIESEL/HEATING OIL NO.2, CHEVRON"
    AD01775 = "DESTIN DOME CIS, MMS"
    AD01776 = "MOTOR GASOLINE-PREMIUM UNLEADED, SHELL REFINING PTY "
    AD01777 = "MOTOR GASOLINE-UNLEADED, SHELL REFINING PTY "
    AD01778 = "MOTOR GASOLINE-LEADED, SHELL REFINING PTY "
    AD01779 = "AUTOMOTIVE DIESEL FUEL, SHELL REFINING PTY "
    AD01786 = "AVIATION TURBINE FUEL, SHELL REFINING PTY "
    AD01800 = "WHITE SPIRIT, SHELL REFINING PTY "
    AD01804 = "NKOSSA, SHELL REFINING PTY "
    AD01805 = "MURBAN, SHELL REFINING PTY "
    AD01806 = "OMAN, SHELL REFINING PTY "
    AD01809 = "GIPPSLAND, SHELL REFINING PTY "
    AD01811 = "THEVENARD, SHELL REFINING PTY "
    AD01812 = "XI-JANG, SHELL REFINING PTY "
    AD01813 = "ATTAKA, SHELL REFINING PTY "
    AD01814 = "ARDJUNA, SHELL REFINING PTY "
    AD01815 = "CINTA, SHELL REFINING PTY "
    AD01816 = "WIDURI, SHELL REFINING PTY "
    AD01817 = "LALANG, SHELL REFINING PTY "
    AD01818 = "MINAS, SHELL REFINING PTY "
    AD01819 = "MAUI, SHELL REFINING PTY "
    AD01820 = "MCKEE, SHELL REFINING PTY "
    AD01822 = "BACH HO, SHELL REFINING PTY "
    AD01823 = "CHALLIS, BHP PETROLEUM"
    AD01824 = "GRIFFIN, BHP PETROLEUM"
    AD01826 = "HARRIET, APACHE ENERGY LTD"
    AD01827 = "STAG, APACHE ENERGY LTD"
    AD01830 = "COOPER BASIN, SANTOS LTD"
    AD01834 = "GIPPSLAND, AMSA"
    AD01850 = "ALASKA NORTH SLOPE-PUMP STATION #9, BP"
    AD01851 = "QATAR NORTH FIELD CONDENSATE (NFR-1), MOBIL"
    AD01853 = "AIRILE, BP"
    AD01854 = "BARROW, BP"
    AD01855 = "BLINA, BP"
    AD01856 = "JACKSON, BP"
    AD01857 = "SURAT BASIN, BP"
    AD01858 = "THEVENAND, BP"
    AD01859 = "VARANUS, BP"
    AD01860 = "WANDO, BP"
    AD01861 = "UMM SHAIF, BP"
    AD01862 = "UPPER ZAKUM, BP"
    AD01863 = "MARGHAM, BP"
    AD01864 = "KUWAIT, BP"
    AD01865 = "KHAFJI, BP"
    AD01866 = "AL RAYYAN, BP"
    AD01868 = "SAJAA CONDENSATE, BP"
    AD01869 = "NANNAI LIGHT, BP"
    AD01870 = "BELIDA, BP"
    AD01872 = "BONTANG MIX, BP"
    AD01873 = "HANDIL, BP"
    AD01874 = "KERAPU, BP"
    AD01876 = "MIRI LIGHT, BP"
    AD01877 = "CHERVIL, NOVUS WA PTY LTD"
    AD01882 = "ARABIAN EXTRA LIGHT, MOBIL OIL AUSTRALIA"
    AD01884 = "BASRAH LIGHT, MOBIL OIL AUSTRALIA"
    AD01885 = "BELIDA, MOBIL OIL AUSTRALIA "
    AD01887 = "EAST SPAB, MOBIL OIL AUSTRALIA"
    AD01888 = "ERAWAN, MOBIL OIL AUSTRALIA "
    AD01889 = "KUTUBU LIGHT, MOBIL OIL AUSTRALIA "
    AD01891 = "QATAR LAND, MOBIL OIL AUSTRALIA "
    AD01892 = "QATAR MARINE, MOBIL OIL AUSTRALIA"
    AD01893 = "THAMMAMA, MOBIL OIL AUSTRALIA "
    AD01894 = "UPPER ZAKUM, MOBIL OIL AUSTRALIA "
    AD01895 = "WANDOO, MOBIL OIL AUSTRALIA"
    AD01896 = "BELIDA, CALTEX"
    AD01897 = "KUKAPU, CALTEX"
    AD01898 = "BEKOPAI, CALTEX"
    AD01899 = "SENIPAH, CALTEX"
    AD01900 = "IMA, CALTEX"
    AD01904 = "ORIENTE, OIL & GAS"
    AD01906 = "MAYA, OIL & GAS"
    AD01907 = "OLMECA, OIL & GAS"
    AD01911 = "BOSCAN, OIL & GAS"
    AD01912 = "LA ROSA MEDIUM, OIL & GAS"
    AD01913 = "MEREY, OIL & GAS"
    AD01916 = "MURBAN, OIL & GAS"
    AD01922 = "BASRAH, OIL & GAS"
    AD01924 = "KIRKUK, OIL & GAS"
    AD01925 = "KUWAIT EXPORT, OIL & GAS"
    AD01927 = "ARABIAN LIGHT, OIL & GAS"
    AD01929 = "SEPINGGAN-YAKIN MIXED, OIL & GAS"
    AD01930 = "SAHARAN BLEND, OIL & GAS"
    AD01938 = "RAINBOW LIGHT AND MEDIUM, OIL & GAS"
    AD01939 = "RANGELAND-SOUTH, OIL & GAS"
    AD01944 = "EKOFISK, OIL & GAS"
    AD01945 = "GULLFAKS, OIL & GAS"
    AD01946 = "OSEBERG, OIL & GAS"
    AD01947 = "ARGYLL, OIL & GAS"
    AD01950 = "BRENT, OIL & GAS"
    AD01970 = "MIX GEISUM, GEISUM OIL"
    AD01971 = "NORTH GEISUM, GEISUM OIL"
    AD01972 = "TAWILA, GEISUM OIL"
    AD01973 = "SOUTH GEISUM, GEISUM OIL"
    AD01978 = "VIOSCA KNOLL BLOCK 990"
    AD01981 = "POSIDEN, EQUILON"
    AD01983 = "ABOOZAR"
    AD01984 = "ABU AL BU KHOOSH"
    AD01985 = "ADGO"
    AD01986 = "ALASKA NORTH SLOPE"
    AD01987 = "ALASKA NORTH SLOPE (MIDDLE PIPELINE)"
    AD01988 = "ALASKA NORTH SLOPE (NORTHERN PIPELINE)"
    AD01989 = "ALASKA NORTH SLOPE (SOCSEX)"
    AD01990 = "ALASKA NORTH SLOPE (SOUTHERN PIPELINE)"
    AD01991 = "ALBA"
    AD01993 = "ALBERTA SWEET MIXED BLEND (PETAWAWA)"
    AD01994 = "ALBERTA SWEET MIXED BLEND (REFERENCE #2)"
    AD01995 = "ALBERTA SWEET MIXED BLEND (REFERENCE #3)"
    AD01998 = "AMAULIGAK"
    AD01999 = "AMNA"
    AD02000 = "ARABIAN"
    AD02002 = "ARABIAN LIGHT"
    AD02003 = "ARABIAN MEDIUM"
    AD02006 = "ARIMBI"
    AD02007 = "ASHTART"
    AD02012 = "ATTAKA"
    AD02014 = "AVALON"
    AD02015 = "AVIATION GASOLINE 100"
    AD02018 = "BACH HO"
    AD02019 = "BACHAQUERO"
    AD02020 = "BADAK"
    AD02021 = "BAHRGANSAR/NOWRUZ"
    AD02022 = "BARROW ISLAND"
    AD02023 = "BASRAH HEAVY"
    AD02024 = "BASRAH LIGHT"
    AD02025 = "BASRAH MEDIUM"
    AD02026 = "BCF 24"
    AD02027 = "BEATRICE"
    AD02028 = "BEKAPAI"
    AD02029 = "BEKOK"
    AD02030 = "BELAYIM"
    AD02032 = "BELRIDGE HEAVY"
    AD02033 = "BENT HORN"
    AD02035 = "BERRI"
    AD02037 = "BETA"
    AD02039 = "BOMBAY HIGH"
    AD02040 = "BONNY LIGHT"
    AD02041 = "BONNY MEDIUM"
    AD02042 = "BOSCAN"
    AD02044 = "BOW RIVER HEAVY"
    AD02045 = "BRAE"
    AD02046 = "BRASS RIVER"
    AD02047 = "BREGA"
    AD02051 = "BUNKER C FUEL OIL"
    AD02052 = "BUNKER C FUEL OIL (ALASKA)"
    AD02053 = "BUNK FUEL OIL (IRVING WHALE)"
    AD02054 = "BUNYU"
    AD02055 = "BURGAN"
    AD02056 = "CABINDA"
    AD02057 = "CALIFORNIA (API 11)"
    AD02058 = "CALIFORNIA (API 15)"
    AD02059 = "CANADON SECO"
    AD02060 = "CANO LIMON"
    AD02061 = "CARPINTERIA"
    AD02063 = "CATALYTIC CRACKING FEED"
    AD02064 = "CEUTA"
    AD02065 = "CHAMPION EXPORT"
    AD02066 = "CINTA"
    AD02067 = "COAL OIL POINT SEEP OIL"
    AD02068 = "COHASSET"
    AD02069 = "COLD LAKE BITUMEN"
    AD02070 = "COLD LAKE BLEND"
    AD02072 = "COOPER BASIN"
    AD02073 = "CORMORANT NORTH"
    AD02074 = "CORMORANT SOUTH"
    AD02076 = "COSSACK"
    AD02077 = "CUSIANA"
    AD02079 = "DAN"
    AD02080 = "DANISH NORTH SEA"
    AD02081 = "DIESEL FUEL OIL (ALASKA)"
    AD02083 = "DIESEL FUEL OIL (SOUTHERN USA 1994)"
    AD02084 = "DIESEL FUEL OIL (SOUTHERN USA 1997)"
    AD02086 = "DJENO BLEND"
    AD02087 = "DORROOD"
    AD02088 = "DOS CUADRAS"
    AD02089 = "DUBAI"
    AD02090 = "DUKHAN"
    AD02093 = "EAST ZEIT MIX"
    AD02094 = "EKOFISK"
    AD02098 = "ELECTRICAL INSULATING OIL (VOLTESSO 35)"
    AD02099 = "EMERALD"
    AD02100 = "EMPIRE"
    AD02101 = "FORCADOS"
    AD02102 = "KOME"
    AD02103 = "MIANDOUM"
    AD02104 = "BOLOBO"
    AD02105 = "CUSIANA, MOTIVA ENTERPRISES LLC"
    AD02107 = "RABI, MOTIVA ENTERPRISES LLC"
    AD02108 = "N'KOSSA EXP BLEND, CHEVRON"
    AD02109 = "ANTAN, HUVENSA"
    AD02110 = "ENDICOTT"
    AD02111 = "EOCENE"
    AD02112 = "ES SIDER"
    AD02113 = "ESCALANTE"
    AD02114 = "ESCRAVOS"
    AD02115 = "ESPOIR"
    AD02116 = "EUGENE ISLAND BLOCK 32"
    AD02117 = "EUGENE ISLAND BLOCK 43"
    AD02118 = "EVERDELL"
    AD02119 = "FEDERATED (1994)"
    AD02120 = "FEDERATED (1998)"
    AD02121 = "FEDERATED (SOCSEX)"
    AD02122 = "FEDERATED LIGHT AND MEDIUM"
    AD02123 = "FLOTTA"
    AD02124 = "FLUID CATALYTIC CRACKER FEED"
    AD02125 = "FLUID CATALYTIC CRACKER HEAVY CYCLE OIL"
    AD02126 = "FLUID CATALYTIC CRACKER LIGHT CYCLE OIL"
    AD02127 = "FLUID CATALYTIC CRACKER MEDIUM CYCLE OIL"
    AD02129 = "FORCADOS BLEND"
    AD02130 = "FOROOZAN"
    AD02131 = "FORTIES BLEND"
    AD02136 = "FUEL OIL NO.1 (JP-6)"
    AD02139 = "FUEL OIL NO.2 (HIGH AROMATIC CONTENT HEATING OIL)"
    AD02144 = "FULMAR"
    AD02145 = "GALEOTA MIX"
    AD02146 = "GAMBA"
    AD02147 = "GARDEN BANKS BLOCK 387"
    AD02148 = "GARDEN BANKS BLOCK 426"
    AD02153 = "GASOLINE (UNLEADED), SHELL"
    AD02156 = "GENESIS"
    AD02157 = "GIPPSLAND"
    AD02158 = "GORM"
    AD02159 = "GRANITE POINT"
    AD02160 = "GREEN CANYON BLOCK 109"
    AD02161 = "GREEN CANYON BLOCK 184"
    AD02162 = "GREEN CANYON BLOCK 65"
    AD02163 = "GRIFFIN"
    AD02164 = "GULF OF SUEZ MIX"
    AD02165 = "GULLFAKS"
    AD02166 = "HANDIL"
    AD02168 = "HEBRON"
    AD02169 = "HEIDRUN"
    AD02170 = "HIBERNIA"
    AD02171 = "HIBERNIA (EPA 86)"
    AD02172 = "HIGH VISCOSITY FUEL OIL"
    AD02174 = "HONDO BLEND"
    AD02175 = "HONDO MONTEREY"
    AD02176 = "HONDO SANDSTONE"
    AD02177 = "HOUT"
    AD02178 = "HYDRA"
    AD02179 = "IF-30 FUEL OIL"
    AD02180 = "IF-30 FUEL OIL (SVALBARD)"
    AD02181 = "IF-30 FUEL OIL 180"
    AD02182 = "INTERMEDIATE FUEL OIL 180 (SOCSEX)"
    AD02183 = "INTERMEDIATE FUEL OIL 300"
    AD02184 = "INTERMEDIATE FUEL OIL 300 (SOCSEX)"
    AD02186 = "IRANIAN HEAVY"
    AD02187 = "IRANIAN LIGHT"
    AD02189 = "ISTHMUS"
    AD02192 = "JATIBARANG"
    AD02197 = "KHALDA"
    AD02198 = "KIMKOL"
    AD02199 = "KIRKUK BLEND"
    AD02200 = "KITTIWAKE"
    AD02201 = "KOAKOAK"
    AD02202 = "KOLE MARINE BLEND"
    AD02203 = "KOMINEFT"
    AD02204 = "KOPANOAR"
    AD02207 = "KUWAIT"
    AD02209 = "LABUAN BLEND"
    AD02210 = "LAGO"
    AD02211 = "LAGO TRECO"
    AD02212 = "LAGOMEDIO"
    AD02213 = "LEONA"
    AD02214 = "LIVERPOOL BAY"
    AD02215 = "LLOYDMINSTER"
    AD02216 = "LORETO"
    AD02217 = "LOUISIANA"
    AD02220 = "LUBRICATING OIL (AIR COMPRESSOR) NEW"
    AD02221 = "LUBRICATING OIL (AIR COMPRESSOR) USED"
    AD02240 = "LUCULA"
    AD02241 = "MAGNUS"
    AD02242 = "MAIN PASS BLOCK 306"
    AD02243 = "MAIN PASS BLOCK 37"
    AD02244 = "MALONGO"
    AD02245 = "MANDJI"
    AD02246 = "MARGHAM LIGHT"
    AD02247 = "MARINE DIESEL FUEL OIL"
    AD02250 = "MARINE INTERMEDIATE FUEL OIL"
    AD02251 = "MARS BLEND"
    AD02252 = "MARS TLP"
    AD02253 = "MAUREEN"
    AD02254 = "MAYA"
    AD02255 = "MAYA (1997)"
    AD02256 = "MEDANITO"
    AD02257 = "MEREY"
    AD02259 = "MIRI LIGHT"
    AD02260 = "MISSISSIPPI CANYON BLOCK 194"
    AD02261 = "MISSISSIPPI CANYON BLOCK 72"
    AD02263 = "MONTROSE"
    AD02264 = "MOUSSE MIX (PETAWAWA)"
    AD02266 = "MURBAN"
    AD02267 = "MURCHISON"
    AD02273 = "NEPTUNE SPAR"
    AD02275 = "NEWFOUNDLAND OFFSHORE BURN EXP SAMPLE #1"
    AD02276 = "NEWFOUNDLAND OFFSHORE BURN EXP SAMPLE #12"
    AD02277 = "NEWFOUNDLAND OFFSHORE BURN EXP SAMPLE #15"
    AD02278 = "NEWFOUNDLAND OFFSHORE BURN EXP SAMPLE #4"
    AD02279 = "NEWFOUNDLAND OFFSHORE BURN EXP SAMPLE #5"
    AD02280 = "NEWFOUNDLAND OFFSHORE BURN EXP SAMPLE #7"
    AD02281 = "NINIAN BLEND"
    AD02282 = "NORMAN WELLS"
    AD02284 = "POINT ARGUELLO COMINGLED"
    AD02286 = "POINT ARGUELLO HEAVY"
    AD02287 = "OMAN EXPORT"
    AD02289 = "ORIENTE"
    AD02290 = "ORIMULSION-100"
    AD02293 = "OSEBERG"
    AD02294 = "PANUKE"
    AD02297 = "PITAS POINT"
    AD02298 = "PLATFORM GAIL"
    AD02299 = "PLATFORM HOLLY"
    AD02300 = "PLATFORM IRENE"
    AD02301 = "POINT ARGUELLO LIGHT"
    AD02302 = "PORT HUENEME"
    AD02304 = "PRUDHOE BAY"
    AD02305 = "PRUDHOE BAY (1995)"
    AD02306 = "PULAI"
    AD02307 = "QATAR MARINE"
    AD02308 = "QUA IBOE"
    AD02311 = "RANGELY"
    AD02312 = "RINCON DE LOS SAUCES"
    AD02314 = "ROSTAM"
    AD02315 = "SABLE ISLAND CONDENSATE"
    AD02316 = "SAHARAN BLEND"
    AD02317 = "SAKHALIN"
    AD02318 = "SALADIN"
    AD02319 = "SALAWATI"
    AD02320 = "SALMON"
    AD02322 = "SANGA SANGA"
    AD02323 = "SANTA CLARA"
    AD02325 = "SCOTIAN LIGHT"
    AD02326 = "SEPINGGAN-YAKIN MIXED (4:1)"
    AD02327 = "SERIA LIGHT"
    AD02329 = "SHENGLI"
    AD02330 = "SHIP SHOAL BLOCK 239"
    AD02331 = "SHIP SHOAL BLOCK 269"
    AD02332 = "SIBERIAN LIGHT"
    AD02333 = "SIRRI"
    AD02335 = "SKUA"
    AD02336 = "SOCKEYE"
    AD02337 = "SOCKEYE COMINGLED"
    AD02338 = "SOCKEYE SOUR"
    AD02339 = "SOCKEYE SWEET"
    AD02340 = "SOROOSH"
    AD02341 = "SOUEDIE"
    AD02344 = "SOUTH PASS BLOCK 60"
    AD02345 = "SOUTH PASS BLOCK 67"
    AD02346 = "SOUTH PASS BLOCK 93"
    AD02347 = "SOUTH TIMBALIER BLOCK 130"
    AD02349 = "SOYO BLEND"
    AD02351 = "STATFJORD"
    AD02352 = "SUMATRAN HEAVY"
    AD02353 = "SUMATRAN LIGHT"
    AD02354 = "SWANSON RIVER"
    AD02356 = "SYNTHETIC"
    AD02358 = "TAKULA"
    AD02359 = "TAPIS"
    AD02360 = "TAPIS BLEND"
    AD02362 = "TARTAN"
    AD02363 = "TEMBUNGO"
    AD02364 = "TERRA NOVA"
    AD02365 = "TERRA NOVA (1994)"
    AD02366 = "TERRA NOVA (PETAWAWA)"
    AD02367 = "TERRA NOVA (SOCSEX)"
    AD02368 = "THEVENARD ISLAND"
    AD02369 = "THISTLE"
    AD02370 = "TIA JUANA HEAVY"
    AD02371 = "TIA JUANA LIGHT"
    AD02373 = "TRADING BAY"
    AD02374 = "TRANSMOUNTAIN BLEND"
    AD02376 = "UDANG"
    AD02381 = "VASCONIA"
    AD02382 = "VIOSCA KNOLL BLOCK 826"
    AD02383 = "VIOSCA KNOLL BLOCK 990"
    AD02384 = "WABASCA BITUMEN"
    AD02385 = "WAINWRIGHT-KINSELLA"
    AD02386 = "WALIO"
    AD02387 = "WAXY LIGHT HEAVY BLEND"
    AD02388 = "WEST DELTA BLOCK 30"
    AD02390 = "WEST SAK"
    AD02391 = "WEST TEXAS INTERMEDIATE"
    AD02392 = "WEST TEXAS SOUR"
    AD02394 = "ZAIRE"
    AD02395 = "ZAKUM"
    AD02396 = "ZARZITINE"
    AD02397 = "ZUEITINA"
    AD02398 = "ZULUF/MARJAN"
    AD02401 = "GULF ALBERTA LIGHT AND MEDIUM"
    AD02402 = "KOAKOAK 0-22A"
    AD02403 = "LUCINA MARINE"
    AD02408 = "BELINDA, AMSA"
    AD02417 = "UPPER ZAKUM, AMSA"
    AD02425 = "JET FUEL, TESORO"
    AD02426 = "HOME HEATING OIL"
    AD02428 = "IFO 300"
    AD02430 = "JP-5"
    AD02431 = "FUEL OIL NO.6"
    AD02433 = "JP-8"
    AD02434 = "JP-8"
    AD02435 = "KUWAIT"
    AD02436 = "DIESEL FUEL OIL NO.2 (BONDED), TESORO"
    AD02437 = "STAR 4, EQUILON"
    AD02438 = "STAR 5, EQUILON"
    AD02439 = "STAR 12, EQUILON"
    AD02440 = "SAKHALIN II"
    AD02441 = "ESCALANTE, ITS"
    AD02447 = "MARINE DIESEL, U.S. NAVY"
    AD02448 = "LUCKENBACH FUEL OIL"
    AD02450 = "SCHIEHALLION BLEND, STATOIL"
    AD02452 = "TROLL, STATOIL"
    AD02454 = "GLITNE, STATOIL"
    AD02455 = "NORNE, STATOIL"
    AD02456 = "LUFENG, STATOIL"
    AD02458 = "VARG, STATOIL"
    AD02459 = "GULLFAKS C, STATOIL"
    AD02460 = "GULLFAKS A, STATOIL"
    AD02462 = "OSEBERG BLEND, STATOIL"
    AD02463 = "EKOFISK BLEND, STATOIL"
    AD02464 = "STATFJORD BLEND, STATOIL"
    AD02466 = "ASGARD, STATOIL"
    AD02467 = "NJORD, STATOIL"
    AD02470 = "GIRASSOL"
    AD02471 = "JOTUN, OIL & GAS JOURNAL"
    AD02472 = "PIERCE, OIL & GAS JOURNAL"
    AD02473 = "TEMPA ROSSA, OIL & GAS JOURNAL"
    AD02474 = "ZUATA SWEET, OIL & GAS JOURNAL"
    AD02477 = "MILNE POINT"
    AD02478 = "LISBURNE"
    AD02479 = "ALPINE SALES OIL"
    AD02480 = "NORTHSTAR"
    AD02481 = "WEST SAK"
    AD02482 = "BACHAQUERO-DELAWARE RIVER, CITGO"
    AD02483 = "CONDENSATE (SWEET), ENCANA CORP."
    AD02538 = "EAGLE FORD SHALE"
    AD02539 = "NAPO"
    AD02540 = "U.S. HIGH SWEET-CLEARBROOK"
    AD02541 = "ULTRA LOW SULFUR DIESEL"
    AD02542 = "ALPINE"
    AD02547 = "HOOPS BLEND, ExxonMobil"
    AD02548 = "AGBAMI, STATOIL"
    AD02549 = "ALBA"
    AD02550 = "ALGERIAN CONDENSATE, STATOIL"
    AD02551 = "ALVHEIM BLEND, STATOIL"
    AD02552 = "AASGARD BLEND, STATOIL"
    AD02553 = "AZERI BTC, STATOIL"
    AD02554 = "AZERI LIGHT, STATOIL"
    AD02555 = "CLOV, STATOIL"
    AD02556 = "DALIA, STATOIL"
    AD02557 = "DRAUGEN, STATOIL"
    AD02558 = "EKOFISK, STATOIL"
    AD02559 = "FORTIES, STATOIL"
    AD02560 = "GIMBO, STATOIL"
    AD02561 = "GIRASSOL, STATOIL"
    AD02562 = "GOLIAT BLEND, STATOIL"
    AD02563 = "GRANE BLEND, STATOIL"
    AD02564 = "GUDRUN BLEND, STATOIL"
    AD02565 = "GULLFAKS, STATOIL"
    AD02566 = "HEIDRUN, STATOIL"
    AD02567 = "HIBERNIA BLEND, STATOIL"
    AD02569 = "HUNGO BLEND, STATOIL"
    AD02570 = "ALASKA NORTH SLOPE, BP"
    AD02572 = "ARABIAN LIGHT"
    AD02579 = "ALASKA NORTH SLOPE 2019"
    AD02580 = "AMSA Average Very Low Sulfur Fuel Oil (VLSFO)"
    AD02582 = "VLSFO O-1 (AMSA)"
    AD02583 = "VLSFO O-2 (AMSA)"
    AD02584 = "VLSFO O-3 (AMSA)"
    AD02585 = "VLSFO O-4 (AMSA)"
    AD02586 = "VLSFO O-5 (AMSA)"
    AD02587 = "VLSFO O-6 (AMSA)"
    AD02588 = "VLSFO O-7 (AMSA)"
    AD02589 = "VLSFO O-8 (AMSA)"
    AD02590 = "VLSFO O-9 (AMSA)"
    AD02591 = "VLSFO O-10 (AMSA)"
    AD02592 = "VLSFO IM-5 (IMAROS)"
    AD02596 = "VLSFO IM-3 (IMAROS)"
    AD02597 = "VLSFO IM-4 (IMAROS)"
    AD02598 = "VLSFO IM-6 (IMAROS)"
    AD02600 = "VLSFO IM-8 (IMAROS)"
    AD02602 = "VLSFO IM-10 (IMAROS)"
    AD02603 = "VLSFO IM-11 (IMAROS)"
    AD02604 = "VLSFO IM-12 (IMAROS)"
    AD02605 = "VLSFO IM-13 (IMAROS)"
    AD02606 = "ULSFO Gas Oil (SINTEF)"
    AD02607 = "ULSFO Marine Gas Oil (SINTEF)"
    AD02608 = "ULSFO Rotterdam Diesel (SINTEF)"
    AD02609 = "VLSFO WRG oil, DMZ-RMA quality (SINTEF)"
    AD02610 = "ULSFO Heavy Distillate Marine ECA 50 (SINTEF)"
    AD02611 = "Ultra Low Sulphur Fuel Oil (ULSFO), RMA-quality oil (SINTEF)"
    AD02612 = "Nile Blend"
    AD02613 = "Nile Blend"
    EC00506 = "Alaminos Canyon Block 25"
    EC00507 = "Alaska North Slope [2002]"
    EC00511 = "Alberta Sweet Mixed Blend #4"
    EC00512 = "Alberta Sweet Mixed Blend #5"
    EC00515 = "Amauligak"
    EC00517 = "Anadarko HIA-376"
    EC00519 = "Arabian Heavy [2004]"
    EC00523 = "Arabian Light [2002]"
    EC00527 = "Atkinson"
    EC00539 = "Bunker C [1987]"
    EC00540 = "Bunker C - IFO-300 [1994]"
    EC00552 = "Chayvo"
    EC00561 = "Cook Inlet [2003]"
    EC00567 = "Diesel [2002]"
    EC00586 = "Fuel Oil # 5"
    EC00593 = "Green Canyon Block 200"
    EC00599 = "Hebron M-04 [2005]"
    EC00601 = "HFO 6303 [2002]"
    EC00604 = "Hibernia [1999]"
    EC00616 = "Issungnak"
    EC00638 = "Mars TLP [2000]"
    EC00643 = "Maya [2004]"
    EC00647 = "Mississippi Canyon Block 807 [2002]"
    EC00648 = "Morpeth Block EW921"
    EC00654 = "Norman Wells"
    EC00658 = "Odoptu"
    EC00668 = "Petronius Block VK786A"
    EC00670 = "Platform Elly"
    EC00679 = "Prudhoe Bay [2004]"
    EC00690 = "Sockeye Sour"
    EC00696 = "South Louisiana"
    EC00698 = "South Louisiana"
    EC00721 = "Troll"
    EC00734 = "West Delta Block 143"
    EC00736 = "West Texas Intermediate [2001]"
    EC00738 = "White Rose [2000]"
    EC01172 = "Albian Heavy Synthetic"
    EC01346 = "Wabiska Heavy"
    EC01456 = "Independent Hub"
    EC01459 = "Neptune BHP [2009]"
    EC01464 = "Platform Irene"
    EC01465 = "Platform Irene Comingled"
    EC01466 = "Gail Well E010"
    EC01467 = "Gail Well E019"
    EC01482 = "Platform Ellen A038"
    EC01483 = "Platform Ellen A040"
    EC01497 = "Alaska North Slope [2010]"
    EC01499 = "Heritage HE 05"
    EC01500 = "Heritage HE 26"
    EC01822 = "Dos Cuadros HE-05 [2011]"
    EC01823 = "Dos Cuadros HE-26 [2011]"
    EC01950 = "Alaska North Slope [2011]"
    EC01951 = "DOBA"
    EC01952 = "Endicott"
    EC01953 = "Harmony"
    EC01955 = "IFO 180"
    EC01956 = "North Star"
    EC01957 = "Rock"
    EC01958 = "Terra Nova [2011]"
    EC01969 = "Bakken"
    EC02152 = "Alaska North Slope [2012]"
    EC02234 = "Access West Blend Winter"
    EC02235 = "Cold Lake Blend Winter [2013]"
    EC02427 = "Cold Lake Blend Summer [2014]"
    EC02664 = "Synthetic Bitumen Blend"
    EC02681 = "Sweet Synthetic Crude Oil [2015b]"
    EC02695 = "Sweet Synthetic Crude Oil [2015a]"
    EC02709 = "Western Canadian Select"
    EC02712 = "Cold Lake Blend Winter [2015]"
    EC02713 = "Alaska North Slope [2015]"
    EC02932 = "Bunker C MV Manolis 2015-May operation"
    EC03048 = "MV Arrow [2015]"
    EC03126 = "Rail Bitumen"
    EC03288 = "Husky Energy SGS"
    EC03629 = "Diesel Echo Bay (B5 Biodiesel)"
    EC04016 = "Terra Nova [2018]"
    EC04026 = "Marine Diesel [2018]"
    EC04028 = "Hibernia [2018]"
    EC04029 = "Hebron [2018]"
    EC04030 = "White Rose [2018]"
    EX00001 = "Aasgard Blend"
    EX00002 = "Alaska North Slope"
    EX00003 = "Azeri Light"
    EX00004 = "Balder Blend"
    EX00005 = "Banyu Urip"
    EX00006 = "Basrah"
    EX00007 = "Basrah Heavy"
    EX00008 = "Bonga"
    EX00009 = "Brent Blend"
    EX00010 = "CLOV"
    EX00011 = "Cold Lake Blend"
    EX00012 = "Curlew"
    EX00013 = "Dalia"
    EX00014 = "Doba Blend"
    EX00015 = "Ebok"
    EX00016 = "Ekofisk"
    EX00017 = "Erha"
    EX00018 = "Forties Blend"
    EX00019 = "Gindungo"
    EX00020 = "Gippsland Blend"
    EX00021 = "Girassol"
    EX00022 = "Gorgon"
    EX00023 = "Grane"
    EX00024 = "Gudrun Blend"
    EX00025 = "Gullfaks Blend"
    EX00026 = "HOOPS Blend"
    EX00027 = "Hebron"
    EX00028 = "Hibernia Blend"
    EX00029 = "Hungo Blend"
    EX00030 = "Jotun Blend"
    EX00031 = "Kearl"
    EX00032 = "Kissanje Blend"
    EX00033 = "Kutubu"
    EX00034 = "Marib Light"
    EX00035 = "Mondo"
    EX00036 = "Mostarda"
    EX00037 = "Ormen Lange"
    EX00038 = "Oseberg Blend"
    EX00039 = "Oso Condensate"
    EX00040 = "Pazflor"
    EX00041 = "Qua Iboe"
    EX00042 = "Sable Island"
    EX00043 = "Saxi Batuque"
    EX00044 = "Sokol"
    EX00045 = "Statfjord Blend"
    EX00046 = "Tapis"
    EX00047 = "Terengganu Condensate"
    EX00048 = "Terra Nova"
    EX00049 = "Thunder Horse"
    EX00050 = "Triton Blend"
    EX00051 = "Troll Blend"
    EX00052 = "Upper Zakum"
    EX00053 = "Usan"
    EX00054 = "Volve"
    EX00055 = "Woollybutt"
    EX00056 = "Yoho"
    EX00057 = "Zafiro Blend"
    EX00058 = "Liza"
    GN00001 = "Generic Condensate"
    GN00002 = "Generic Diesel"
    GN00003 = "Generic Gasoline"
    GN00004 = "Generic Heavy Crude"
    GN00005 = "Generic Jet Fuel"
    GN00006 = "Generic Light Crude"
    GN00007 = "Generic Medium Crude"
    LS00009 = "DMA (ULSFO)"
    LS00010 = "DMB (ULSFO)"
    NO00001 = "ALVE 2010"
    NO00002 = "ALVHEIM BLEND 2009"
    NO00003 = "ALVHEIM BOA 2009"
    NO00004 = "ALVHEIM KAMELEON 2009"
    NO00005 = "ALVHEIM KNELER 2009"
    NO00006 = "AVALDSNES 2012"
    NO00007 = "BALDER 2002"
    NO00008 = "BALDER BLEND 2010"
    NO00009 = "BRAGE 2013"
    NO00010 = "BREAM 2011"
    NO00011 = "CAURUS 2011"
    NO00012 = "DRAUGEN 2008"
    NO00013 = "EKOFISK 2002"
    NO00014 = "EKOFISK BLEND 2000"
    NO00015 = "EKOFISK BLEND 2011"
    NO00016 = "EKOFISK J 2015"
    NO00017 = "ELDFISK 2002"
    NO00018 = "ELDFISK B 2015"
    NO00019 = "ELDFISK BLEND 2011"
    NO00020 = "ELDFISK KOMPLEKS 2015"
    NO00021 = "ELLI 1999"
    NO00022 = "ELLI SOUTH 1999"
    NO00023 = "EMBLA 2002"
    NO00024 = "FORSETI 2002"
    NO00025 = "FOSSEKALL 2013"
    NO00026 = "FRAM 2013"
    NO00027 = "FROY 1996"
    NO00028 = "GARANTIANA 2013"
    NO00029 = "GAUPE 2011"
    NO00030 = "GJOA 2011"
    NO00031 = "GLITNE 2002"
    NO00032 = "GOLIAT BLEND 50/50 2008"
    NO00033 = "GOLIAT BLEND 70/30 2008"
    NO00034 = "GOLIAT KOBBE 2008"
    NO00035 = "GOLIAT REALGRUNNEN 2008"
    NO00036 = "GRANE 1997"
    NO00037 = "GROSBEAK 2012"
    NO00038 = "GUDRUN 2012"
    NO00039 = "GULLFAKS A BLEND 2010"
    NO00040 = "GULLFAKS C BLEND 2010"
    NO00041 = "GULLFAKS SOR 1996"
    NO00042 = "GYDA 2002"
    NO00043 = "HAVIS 2013"
    NO00044 = "HEIDRUN EXPORT BLEND 2004"
    NO00045 = "HEIDRUN TILJE 2004"
    NO00046 = "HEIDRUN AaRE 2004"
    NO00047 = "HULDRA KONDENSAT 1998"
    NO00048 = "IFO-180LS 2014"
    NO00049 = "IFO-180NS 2014"
    NO00050 = "IFO-80LS 2014"
    NO00051 = "IFO-380LS 2014"
    NO00052 = "IVAR AASEN 2012"
    NO00053 = "JORDBAER 2011"
    NO00054 = "KRISTIN 2006"
    NO00055 = "KVITEBJORN 2009"
    NO00056 = "LAVRANS 1997"
    NO00057 = "LILLEFRIGG KONDENSAT 1996"
    NO00058 = "LINERLE 2005"
    NO00059 = "LUNO 2011"
    NO00060 = "LUNO II 2014"
    NO00061 = "MARIA 2013"
    NO00062 = "MIDGARD 1991"
    NO00063 = "MORVIN 2008"
    NO00064 = "NJORD 1997"
    NO00065 = "NORNE 1997"
    NO00066 = "NORNE BLEND 2010"
    NO00067 = "ORMEN LANGE KONDENSAT 2008"
    NO00068 = "OSEBERG A 2013"
    NO00069 = "OSEBERG SOR 2013"
    NO00070 = "OSEBERG OST 2013"
    NO00071 = "OSELVAR 2012"
    NO00072 = "RINGHORNE 2002"
    NO00073 = "SKARFJELL 2014"
    NO00074 = "SKARV 2004"
    NO00075 = "SKARV KONDENSAT 2014"
    NO00076 = "SKRUGARD 2012"
    NO00077 = "SLEIPNER KONDENSAT 2002"
    NO00078 = "SLEIPNER VEST 1998"
    NO00079 = "SMORBUKK 2003"
    NO00080 = "SMORBUKK KONDENSAT 2003"
    NO00081 = "SMORBUKK SOR 2003"
    NO00082 = "SNORRE B 2004"
    NO00083 = "SNORRE TLP 2004"
    NO00084 = "SNOHVIT KONDENSAT 2001"
    NO00085 = "STATFJORD A 2001"
    NO00086 = "STATFJORD B 2001"
    NO00087 = "STATFJORD C 2001"
    NO00088 = "STAER 2010"
    NO00089 = "TAMBAR 2002"
    NO00090 = "TAU 1999"
    NO00091 = "TOR 2002"
    NO00092 = "TORDIS 2002"
    NO00093 = "TRESTAKK 2008"
    NO00094 = "TRYM KONDENSAT 2011"
    NO00095 = "TYRIHANS NORD 2004"
    NO00096 = "TYRIHANS SOR 2004"
    NO00097 = "ULA 1999"
    NO00098 = "VALE 2014"
    NO00099 = "VALHALL 2002"
    NO00100 = "VARG 2000"
    NO00101 = "VESLEFRIKK 2012"
    NO00102 = "VIGDIS 2004"
    NO00103 = "VILJE 2009"
    NO00104 = "VISUND 2009"
    NO00105 = "VOLUND 2010"
    NO00106 = "VOLVE 2006"
    NO00107 = "WISTING 2015"
    NO00108 = "AASGARD A 2003"
    NO00109 = "SVALIN 2014"
    NO00110 = "ALTA 2016"
    NO00111 = "DRIVIS 2017"
    NO00112 = "MARTIN LINGE CRUDE 2016"
    NO00113 = "MARTIN LINGE CONDENSATE 2016"
    NO00114 = "BRYNHILD CRUDE 2015"
    NO00115 = "BOYLA CRUDE 2016"
    NO00116 = "WISTING CENTRAL 2017"
    NO00117 = "SIGYN CONDENSATE 2017"
    NO00118 = "NORNE CRUDE 2017"
    NO00119 = "MARINE GAS OIL 500 ppm S 2017"
    NO00120 = "ULTRA LOW SULFUR FUEL OIL 2017"
    NO00121 = "HEAVY DISTILLATE MARINE ECA 50 2017"
    NO00122 = "ROTTERDAM DIESEL 2017"
    NO00123 = "GAS OIL 10 ppm S 2017"
    NO00124 = "WIDE RANGE GAS OIL 2017"
    NO00125 = "OSEBERG BLEND 2007"
    NO00126 = "BRASSE 2018"
    NO00127 = "OSEBERG C 2013"
    NO00128 = "VEGA CONDENSATE 2015"
    NO00129 = "FENJA (PIL) 2015"
    NO00130 = "MARULK 2014"
    NO00131 = "GINA KROG CRUDE 2018"
    NO00132 = "GUDRUN 2019"
    NO00133 = "ATLA KONDENSAT 2013"
    NO00134 = "OSEBERG SOR 2000"
    NO00135 = "KVITEBJORN 2019"
    NO00136 = "ODA 2019"
    NO00137 = "IRIS CONDENSATE 2020"
    NO00138 = "AASTA HANSTEEN BLEND 2020"
    NO00139 = "VISUND SOR CONDENSATE 2020"
    NO00140 = "VISUND CRUDE OIL 2020"
    NO00141 = "OSEBERG OST 1998"
    NO00142 = "FROSK 2020"
    NO00143 = "DVALIN 2020"
    NO00144 = "SKOGUL 2020"
    NO00145 = "FOGELBERG CONDENSATE 2021"
    NO00146 = "UTGARD CONDENSATE 2021"
    NO00147 = "NJORD 2003"
    NO00148 = "DUVA 2021"
    NO00149 = "VALHALL 2021"
    NO00150 = "SF NORD BRENT 2021"
    NO00151 = "SYGNA BRENT 2021"
    NO00152 = "ALVE 2014"
    NO00153 = "OSEBERG C 1995"
    NO00154 = "DUGONG 2022"
    NO00155 = "LILLE PRINSEN 2022"
    NO00156 = "TOR II 2022"
    NO00157 = "VALE 2001"
    NO00158 = "GOLIAT REALGRUNNEN 2001"
    NO00159 = "SVALE 2010"
    NO00160 = "BREIDABLIKK 2023"
    NO00162 = "YME 2023"
    NO00163 = "OFELIA 2023"
    NO00164 = "HEIDRUN AARE 2023"
    NO00165 = "LANGFJELLET 2023"
    NO00166 = "CALYPSO 2024"
    AD04000 = "GENERIC LIGHT CRUDE"
    AD04001 = "GENERIC MEDIUM CRUDE"
    AD04002 = "GENERIC HEAVY CRUDE"
    AD04003 = "GENERIC GASOLINE"
    AD04006 = "GENERIC FUEL OIL No.2"
    AD04007 = "GENERIC DIESEL"
    AD04008 = "GENERIC HOME HEATING OIL"
    AD04009 = "GENERIC INTERMEDIATE FUEL OIL 180"
    AD04010 = "GENERIC INTERMEDIATE FUEL OIL 300"
    AD04011 = "GENERIC FUEL OIL No. 6"
    AD04012 = "GENERIC BUNKER C"
    AD04013 = "GENERIC HEAVY FUEL OIL"


class DropletSizeDistributionEnum(str, Enum):
    """Enum for droplet size distribution types."""

    uniform = "uniform"
    normal = "normal"
    lognormal = "lognormal"


class ModifyOilTypeJsonSchema(GenerateJsonSchema):
    """Use this to modify the JSON schema for the OpenOilModelConfig.

    Doesn't hurt to use with any other model.

    Example
    -------

    >>> ptm.OpenDriftModel.model_json_schema(schema_generator=MyGenerateJsonSchema)
    """

    def generate(self, schema, mode="validation"):
        """Generate modified JSON schema for the OpenOilModelConfig."""
        schema = super().generate(schema, mode=mode)

        # List of enum values and corresponding titles
        enum_values = []
        for name, value in OilTypeEnum.__members__.items():
            enum_values.append(
                {
                    "const": name,  # The unique ID (enum name)
                    "title": value,  # The human-readable title which might be duplicated (enum value)
                }
            )

        # Modify the model schema to include the 'oneOf' list for the enum values
        schema["properties"]["oil_type"] = {
            "type": "string",
            "oneOf": enum_values,  # 'oneOf' will have the enum value with both 'const' and 'title'
        }

        return schema
